texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

texinfo update (Sun Dec 2 20:53:01 EST 2007)


From: Karl Berry
Subject: texinfo update (Sun Dec 2 20:53:01 EST 2007)
Date: Sun, 02 Dec 2007 20:53:04 -0500

Index: ChangeLog
===================================================================
RCS file: /sources/texinfo/texinfo/ChangeLog,v
retrieving revision 1.782
retrieving revision 1.783
diff -u -r1.782 -r1.783
--- ChangeLog   30 Nov 2007 17:58:52 -0000      1.782
+++ ChangeLog   3 Dec 2007 01:49:07 -0000       1.783
@@ -1,3 +1,16 @@
+2007-12-02  Karl Berry  <address@hidden>
+
+       * info/info.c (main): undo change of 2006-08-13 in this file,
+       so info can be easily tested in multibyte locales.
+
+       * all files: use the multibyte case comparison functions
+       mbscasecmp and mbsncasecmp from gnulib, instead of simply
+       strcasecmp and strncasecmp.  (1) gnulib strcase is buggy,
+       declaring the str* functions in string.h instead of strings.h,
+       leading to build failure on AIX 4.3.3 (report from Gary E. Barnes,
+       21 Nov 2007 12:37:12).  (2) we want to support multibyte locales
+       better anyway.
+
 2007-11-30  Sergey Poznyakoff  <address@hidden>
 
        * doc/Makeinfo.am: Rename txi-no.tex to txi-nb.tex (see
Index: system.h
===================================================================
RCS file: /sources/texinfo/texinfo/system.h,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- system.h    1 Jul 2007 21:20:28 -0000       1.6
+++ system.h    3 Dec 2007 01:38:41 -0000       1.7
@@ -1,5 +1,5 @@
 /* system.h: system-dependent declarations; include this first.
-   $Id: system.h,v 1.6 2007/07/01 21:20:28 karl Exp $
+   $Id: system.h,v 1.7 2007/12/03 01:38:41 karl Exp $
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
    2006, 2007 Free Software Foundation, Inc.
@@ -80,14 +80,6 @@
 #define PATH_MAX _POSIX_PATH_MAX
 #endif
 
-#ifndef HAVE_DECL_STRCASECMP
-extern int strcasecmp ();
-#endif
-
-#ifndef HAVE_DECL_STRNCASECMP
-extern int strncasecmp ();
-#endif
-
 #ifndef HAVE_DECL_STRCOLL
 extern int strcoll ();
 #endif
@@ -192,8 +184,8 @@
 #  define STRIP_DOT_EXE        1
 # endif /* O_BINARY && !__CYGWIN__ */
   /* Back to any O_BINARY system.  */
-# define FILENAME_CMP  strcasecmp
-# define FILENAME_CMPN strncasecmp
+# define FILENAME_CMP  mbscasecmp
+# define FILENAME_CMPN mbsncasecmp
 # define FOPEN_RBIN    "rb"
 # define FOPEN_WBIN    "wb"
 # define HAVE_DRIVE(n) ((n)[0] && (n)[1] == ':')
Index: gnulib/lib/.cvsignore
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/lib/.cvsignore,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -r1.11 -r1.12
--- gnulib/lib/.cvsignore       26 Nov 2007 19:12:39 -0000      1.11
+++ gnulib/lib/.cvsignore       3 Dec 2007 01:38:41 -0000       1.12
@@ -24,3 +24,6 @@
 unistd.in.h
 wchar.in.h
 wctype.in.h
+mbscasecmp.c
+mbsncasecmp.c
+stdbool.in.h
Index: gnulib/lib/Makefile.am
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/lib/Makefile.am,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -r1.19 -r1.20
--- gnulib/lib/Makefile.am      26 Nov 2007 19:12:39 -0000      1.19
+++ gnulib/lib/Makefile.am      3 Dec 2007 01:38:41 -0000       1.20
@@ -9,7 +9,7 @@
 # the same distribution terms as the rest of that program.
 #
 # Generated by gnulib-tool.
-# Reproduce by: gnulib-tool --import --dir=. --lib=libgnu 
--source-base=gnulib/lib --m4-base=gnulib/m4 --doc-base=doc --aux-dir=build-aux 
--no-libtool --macro-prefix=gl getopt gettext mbswidth memcpy memmove mkstemp 
strcase strdup strerror xalloc xsetenv
+# Reproduce by: gnulib-tool --import --dir=. --lib=libgnu 
--source-base=gnulib/lib --m4-base=gnulib/m4 --doc-base=doc --aux-dir=build-aux 
--no-libtool --macro-prefix=gl getopt gettext mbscasecmp mbsncasecmp mbswidth 
memcpy memmove mkstemp strdup strerror xalloc xsetenv
 
 AUTOMAKE_OPTIONS = 1.5 gnits subdir-objects
 
@@ -281,12 +281,47 @@
 
 ## end   gnulib module malloca
 
+## begin gnulib module mbchar
+
+libgnu_a_SOURCES += mbchar.c
+
+EXTRA_DIST += mbchar.h
+
+## end   gnulib module mbchar
+
+## begin gnulib module mbscasecmp
+
+libgnu_a_SOURCES += mbscasecmp.c
+
+## end   gnulib module mbscasecmp
+
+## begin gnulib module mbsncasecmp
+
+libgnu_a_SOURCES += mbsncasecmp.c
+
+## end   gnulib module mbsncasecmp
+
 ## begin gnulib module mbswidth
 
 libgnu_a_SOURCES += mbswidth.h mbswidth.c
 
 ## end   gnulib module mbswidth
 
+## begin gnulib module mbuiter
+
+libgnu_a_SOURCES += mbuiter.h
+
+## end   gnulib module mbuiter
+
+## begin gnulib module memchr
+
+
+EXTRA_DIST += memchr.c
+
+EXTRA_libgnu_a_SOURCES += memchr.c
+
+## end   gnulib module memchr
+
 ## begin gnulib module memcpy
 
 
@@ -323,6 +358,24 @@
 
 ## end   gnulib module setenv
 
+## begin gnulib module stdbool
+
+BUILT_SOURCES += $(STDBOOL_H)
+
+# We need the following in order to create <stdbool.h> when the system
+# doesn't have one that works.
+stdbool.h: stdbool.in.h
+       rm -f address@hidden $@
+       { echo '/* DO NOT EDIT! GENERATED AUTOMATICALLY! */'; \
+         sed -e 's/@''HAVE__BOOL''@/$(HAVE__BOOL)/g' < $(srcdir)/stdbool.in.h; 
\
+       } > address@hidden
+       mv address@hidden $@
+MOSTLYCLEANFILES += stdbool.h stdbool.h-t
+
+EXTRA_DIST += stdbool.in.h
+
+## end   gnulib module stdbool
+
 ## begin gnulib module stdint
 
 BUILT_SOURCES += $(STDINT_H)
@@ -398,15 +451,6 @@
 
 ## end   gnulib module stdlib
 
-## begin gnulib module strcase
-
-
-EXTRA_DIST += strcasecmp.c strncasecmp.c
-
-EXTRA_libgnu_a_SOURCES += strcasecmp.c strncasecmp.c
-
-## end   gnulib module strcase
-
 ## begin gnulib module strdup
 
 
@@ -499,6 +543,12 @@
 
 ## end   gnulib module string
 
+## begin gnulib module strnlen1
+
+libgnu_a_SOURCES += strnlen1.h strnlen1.c
+
+## end   gnulib module strnlen1
+
 ## begin gnulib module sys_stat
 
 BUILT_SOURCES += $(SYS_STAT_H)
Index: gnulib/lib/mbchar.c
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/lib/mbchar.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- gnulib/lib/mbchar.c 31 Oct 2006 19:34:00 -0000      1.3
+++ gnulib/lib/mbchar.c 3 Dec 2007 01:38:42 -0000       1.4
@@ -1,9 +1,9 @@
 /* Copyright (C) 2001, 2006 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -11,8 +11,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include <config.h>
Index: gnulib/lib/mbchar.h
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/lib/mbchar.h,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- gnulib/lib/mbchar.h 9 Jan 2007 14:09:11 -0000       1.7
+++ gnulib/lib/mbchar.h 3 Dec 2007 01:38:42 -0000       1.8
@@ -1,10 +1,10 @@
 /* Multibyte character data type.
-   Copyright (C) 2001, 2005-2006 Free Software Foundation, Inc.
+   Copyright (C) 2001, 2005-2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* Written by Bruno Haible <address@hidden>.  */
 
@@ -157,8 +156,6 @@
 #include <wchar.h>
 #include <wctype.h>
 
-#include "wcwidth.h"
-
 #define MBCHAR_BUF_SIZE 24
 
 struct mbchar
Index: gnulib/lib/mbuiter.h
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/lib/mbuiter.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- gnulib/lib/mbuiter.h        18 Jun 2006 23:39:43 -0000      1.1
+++ gnulib/lib/mbuiter.h        3 Dec 2007 01:38:42 -0000       1.2
@@ -1,10 +1,10 @@
 /* Iterating through multibyte strings: macros for multi-byte encodings.
-   Copyright (C) 2001, 2005 Free Software Foundation, Inc.
+   Copyright (C) 2001, 2005, 2007 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* Written by Bruno Haible <address@hidden>.  */
 
@@ -73,6 +72,9 @@
    mbui_reloc (iter, ptrdiff)
      relocates iterator when the string is moved by ptrdiff bytes.
 
+   mbui_copy (&destiter, &srciter)
+     copies srciter to destiter.
+
    Here are the function prototypes of the macros.
 
    extern void         mbui_init (mbui_iterator_t iter, const char *startptr);
@@ -81,6 +83,7 @@
    extern mbchar_t     mbui_cur (mbui_iterator_t iter);
    extern const char * mbui_cur_ptr (mbui_iterator_t iter);
    extern void         mbui_reloc (mbui_iterator_t iter, ptrdiff_t ptrdiff);
+   extern void         mbui_copy (mbui_iterator_t *new, const mbui_iterator_t 
*old);
  */
 
 #ifndef _MBUITER_H
@@ -88,7 +91,9 @@
 
 #include <assert.h>
 #include <stdbool.h>
+#include <stddef.h>
 #include <stdlib.h>
+#include <string.h>
 
 /* Tru64 with Desktop Toolkit C has a bug: <stdio.h> must be included before
    <wchar.h>.
@@ -182,6 +187,17 @@
   iter->cur.ptr += ptrdiff;
 }
 
+static inline void
+mbuiter_multi_copy (struct mbuiter_multi *new_iter, const struct mbuiter_multi 
*old_iter)
+{
+  if ((new_iter->in_shift = old_iter->in_shift))
+    memcpy (&new_iter->state, &old_iter->state, sizeof (mbstate_t));
+  else
+    memset (&new_iter->state, 0, sizeof (mbstate_t));
+  new_iter->next_done = old_iter->next_done;
+  mb_copy (&new_iter->cur, &old_iter->cur);
+}
+
 /* Iteration macros.  */
 typedef struct mbuiter_multi mbui_iterator_t;
 #define mbui_init(iter, startptr) \
@@ -200,4 +216,7 @@
 /* Relocation.  */
 #define mbui_reloc(iter, ptrdiff) mbuiter_multi_reloc (&iter, ptrdiff)
 
+/* Copying an iterator.  */
+#define mbui_copy mbuiter_multi_copy
+
 #endif /* _MBUITER_H */
Index: gnulib/lib/memchr.c
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/lib/memchr.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- gnulib/lib/memchr.c 15 Oct 2006 21:09:15 -0000      1.2
+++ gnulib/lib/memchr.c 3 Dec 2007 01:38:42 -0000       1.3
@@ -10,9 +10,9 @@
 NOTE: The canonical source of this file is maintained with the GNU C Library.
 Bugs can be reported to address@hidden
 
-This program is free software; you can redistribute it and/or modify it
+This program is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
+Free Software Foundation; either version 3 of the License, or any
 later version.
 
 This program is distributed in the hope that it will be useful,
@@ -21,8 +21,7 @@
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software Foundation,
-Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #ifndef _LIBC
 # include <config.h>
cvs diff: Tag HEAD refers to a dead (removed) revision in file 
`gnulib/lib/strcasecmp.c'.
cvs diff: No comparison available.  Pass `-N' to `cvs diff'?
cvs diff: Tag HEAD refers to a dead (removed) revision in file 
`gnulib/lib/strncasecmp.c'.
cvs diff: No comparison available.  Pass `-N' to `cvs diff'?
Index: gnulib/lib/strnlen1.c
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/lib/strnlen1.c,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- gnulib/lib/strnlen1.c       2 Nov 2006 00:41:05 -0000       1.4
+++ gnulib/lib/strnlen1.c       3 Dec 2007 01:38:42 -0000       1.5
@@ -1,10 +1,10 @@
 /* Find the length of STRING + 1, but scan at most MAXLEN bytes.
    Copyright (C) 2005-2006 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 
Index: gnulib/lib/strnlen1.h
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/lib/strnlen1.h,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- gnulib/lib/strnlen1.h       22 Aug 2006 12:08:40 -0000      1.2
+++ gnulib/lib/strnlen1.h       3 Dec 2007 01:38:42 -0000       1.3
@@ -1,10 +1,10 @@
 /* Find the length of STRING + 1, but scan at most MAXLEN bytes.
    Copyright (C) 2005 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #ifndef _STRNLEN1_H
 #define _STRNLEN1_H
Index: gnulib/m4/.cvsignore
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/m4/.cvsignore,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- gnulib/m4/.cvsignore        8 Oct 2007 18:22:27 -0000       1.4
+++ gnulib/m4/.cvsignore        3 Dec 2007 01:38:42 -0000       1.5
@@ -1,3 +1,5 @@
 .deps
 .dirstamp
 malloc.m4
+mbscasecmp.m4
+mbsncasecmp.m4
Index: gnulib/m4/gnulib-cache.m4
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/m4/gnulib-cache.m4,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- gnulib/m4/gnulib-cache.m4   23 Jul 2007 14:23:07 -0000      1.7
+++ gnulib/m4/gnulib-cache.m4   3 Dec 2007 01:38:42 -0000       1.8
@@ -15,11 +15,11 @@
 
 
 # Specification in the form of a command-line invocation:
-#   gnulib-tool --import --dir=. --lib=libgnu --source-base=gnulib/lib 
--m4-base=gnulib/m4 --doc-base=doc --aux-dir=build-aux --no-libtool 
--macro-prefix=gl getopt gettext mbswidth memcpy memmove mkstemp strcase strdup 
strerror xalloc xsetenv
+#   gnulib-tool --import --dir=. --lib=libgnu --source-base=gnulib/lib 
--m4-base=gnulib/m4 --doc-base=doc --aux-dir=build-aux --no-libtool 
--macro-prefix=gl getopt gettext mbscasecmp mbsncasecmp mbswidth memcpy memmove 
mkstemp strdup strerror xalloc xsetenv
 
 # Specification in the form of a few gnulib-tool.m4 macro invocations:
 gl_LOCAL_DIR([])
-gl_MODULES([getopt gettext mbswidth memcpy memmove mkstemp strcase strdup 
strerror xalloc xsetenv])
+gl_MODULES([getopt gettext mbscasecmp mbsncasecmp mbswidth memcpy memmove 
mkstemp strdup strerror xalloc xsetenv])
 gl_AVOID([])
 gl_SOURCE_BASE([gnulib/lib])
 gl_M4_BASE([gnulib/m4])
Index: gnulib/m4/gnulib-comp.m4
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/m4/gnulib-comp.m4,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -r1.17 -r1.18
--- gnulib/m4/gnulib-comp.m4    26 Nov 2007 19:12:42 -0000      1.17
+++ gnulib/m4/gnulib-comp.m4    3 Dec 2007 01:38:42 -0000       1.18
@@ -59,16 +59,23 @@
   gl_FUNC_MALLOC_POSIX
   gl_STDLIB_MODULE_INDICATOR([malloc-posix])
   gl_MALLOCA
+  gl_MBCHAR
+  gl_FUNC_MBSCASECMP
+  gl_STRING_MODULE_INDICATOR([mbscasecmp])
+  gl_FUNC_MBSNCASECMP
+  gl_STRING_MODULE_INDICATOR([mbsncasecmp])
   gl_MBSWIDTH
+  gl_MBITER
+  gl_FUNC_MEMCHR
   gl_FUNC_MEMCPY
   gl_FUNC_MEMMOVE
   gl_FUNC_MKSTEMP
   gl_STDLIB_MODULE_INDICATOR([mkstemp])
   gl_FUNC_SETENV
   gl_FUNC_UNSETENV
+  AM_STDBOOL_H
   gl_STDINT_H
   gl_STDLIB_H
-  gl_STRCASE
   gl_FUNC_STRDUP
   gl_STRING_MODULE_INDICATOR([strdup])
   gl_FUNC_STRERROR
@@ -160,8 +167,14 @@
   lib/malloca.c
   lib/malloca.h
   lib/malloca.valgrind
+  lib/mbchar.c
+  lib/mbchar.h
+  lib/mbscasecmp.c
+  lib/mbsncasecmp.c
   lib/mbswidth.c
   lib/mbswidth.h
+  lib/mbuiter.h
+  lib/memchr.c
   lib/memcpy.c
   lib/memmove.c
   lib/mkstemp.c
@@ -169,14 +182,15 @@
   lib/ref-del.sin
   lib/setenv.c
   lib/setenv.h
+  lib/stdbool.in.h
   lib/stdint.in.h
   lib/stdlib.in.h
-  lib/strcasecmp.c
   lib/strdup.c
   lib/streq.h
   lib/strerror.c
   lib/string.in.h
-  lib/strncasecmp.c
+  lib/strnlen1.c
+  lib/strnlen1.h
   lib/sys_stat.in.h
   lib/sys_time.in.h
   lib/tempname.c
@@ -227,9 +241,14 @@
   m4/longlong.m4
   m4/malloc.m4
   m4/malloca.m4
+  m4/mbchar.m4
+  m4/mbiter.m4
   m4/mbrtowc.m4
+  m4/mbscasecmp.m4
+  m4/mbsncasecmp.m4
   m4/mbstate_t.m4
   m4/mbswidth.m4
+  m4/memchr.m4
   m4/memcpy.m4
   m4/memmove.m4
   m4/mkstemp.m4
@@ -240,10 +259,10 @@
   m4/progtest.m4
   m4/setenv.m4
   m4/size_max.m4
+  m4/stdbool.m4
   m4/stdint.m4
   m4/stdint_h.m4
   m4/stdlib_h.m4
-  m4/strcase.m4
   m4/strdup.m4
   m4/strerror.m4
   m4/string_h.m4
Index: gnulib/m4/mbchar.m4
===================================================================
RCS file: /sources/texinfo/texinfo/gnulib/m4/mbchar.m4,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- gnulib/m4/mbchar.m4 9 Jan 2007 14:09:11 -0000       1.4
+++ gnulib/m4/mbchar.m4 3 Dec 2007 01:38:42 -0000       1.5
@@ -1,5 +1,5 @@
-# mbchar.m4 serial 4
-dnl Copyright (C) 2005-2006 Free Software Foundation, Inc.
+# mbchar.m4 serial 7
+dnl Copyright (C) 2005-2007 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
 dnl with or without modifications, as long as this notice is preserved.
@@ -9,12 +9,5 @@
 
 AC_DEFUN([gl_MBCHAR],
 [
-  AC_REQUIRE([AC_GNU_SOURCE])
-  dnl The following line is that so the user can test HAVE_WCHAR_H
-  dnl before #include "mbchar.h".
-  AC_CHECK_HEADERS_ONCE([wchar.h])
-  dnl Compile mbchar.c only if HAVE_WCHAR_H.
-  if test $ac_cv_header_wchar_h = yes; then
-    AC_LIBOBJ([mbchar])
-  fi
+  AC_REQUIRE([AC_USE_SYSTEM_EXTENSIONS])
 ])
cvs diff: Tag HEAD refers to a dead (removed) revision in file 
`gnulib/m4/strcase.m4'.
cvs diff: No comparison available.  Pass `-N' to `cvs diff'?
Index: info/echo-area.c
===================================================================
RCS file: /sources/texinfo/texinfo/info/echo-area.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- info/echo-area.c    1 Jul 2007 21:20:29 -0000       1.10
+++ info/echo-area.c    3 Dec 2007 01:38:42 -0000       1.11
@@ -1,5 +1,5 @@
 /* echo-area.c -- how to read a line in the echo area.
-   $Id: echo-area.c,v 1.10 2007/07/01 21:20:29 karl Exp $
+   $Id: echo-area.c,v 1.11 2007/12/03 01:38:42 karl Exp $
 
    Copyright (C) 1993, 1997, 1998, 1999, 2001, 2004, 2007
    Free Software Foundation, Inc.
@@ -853,7 +853,7 @@
           /* If one of the completions matches exactly, then that is okay, so
              return the current line. */
           for (i = 0; i < completions_found_index; i++)
-            if (strcasecmp (completions_found[i]->label, line) == 0)
+            if (mbscasecmp (completions_found[i]->label, line) == 0)
               {
                 free (line);
                 line = xstrdup (completions_found[i]->label);
@@ -1208,7 +1208,7 @@
 
   for (i = 0; (entry = echo_area_completion_items[i]); i++)
     {
-      if (strncasecmp (request, entry->label, len) == 0)
+      if (mbsncasecmp (request, entry->label, len) == 0)
         add_pointer_to_array (entry, completions_found_index,
                               completions_found, completions_found_slots,
                               20, REFERENCE *);
@@ -1291,7 +1291,7 @@
   REFERENCE **e1 = (REFERENCE **) entry1;
   REFERENCE **e2 = (REFERENCE **) entry2;
 
-  return (strcasecmp ((*e1)->label, (*e2)->label));
+  return (mbscasecmp ((*e1)->label, (*e2)->label));
 }
 
 /* Prune duplicate entries from COMPLETIONS_FOUND. */
Index: info/filesys.c
===================================================================
RCS file: /sources/texinfo/texinfo/info/filesys.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- info/filesys.c      1 Jul 2007 21:20:29 -0000       1.9
+++ info/filesys.c      3 Dec 2007 01:38:42 -0000       1.10
@@ -1,5 +1,5 @@
 /* filesys.c -- filesystem specific functions.
-   $Id: filesys.c,v 1.9 2007/07/01 21:20:29 karl Exp $
+   $Id: filesys.c,v 1.10 2007/12/03 01:38:42 karl Exp $
 
    Copyright (C) 1993, 1997, 1998, 2000, 2002, 2003, 2004, 2007
    Free Software Foundation, Inc.
@@ -693,7 +693,7 @@
       strcpy (trydir, "dir");
       strcat (trydir, info_suffixes[i]);
       
-      if (strcasecmp (filename, trydir) == 0)
+      if (mbscasecmp (filename, trydir) == 0)
         return 1;
 
       for (c = 0; compress_suffixes[c].suffix; c++)
@@ -701,7 +701,7 @@
           char dir_compressed[50]; /* can be short */
           strcpy (dir_compressed, trydir); 
           strcat (dir_compressed, compress_suffixes[c].suffix);
-          if (strcasecmp (filename, dir_compressed) == 0)
+          if (mbscasecmp (filename, dir_compressed) == 0)
             return 1;
         }
     }  
Index: info/info-utils.c
===================================================================
RCS file: /sources/texinfo/texinfo/info/info-utils.c,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- info/info-utils.c   4 Aug 2007 10:59:45 -0000       1.8
+++ info/info-utils.c   3 Dec 2007 01:38:42 -0000       1.9
@@ -1,5 +1,5 @@
 /* info-utils.c -- miscellanous.
-   $Id: info-utils.c,v 1.8 2007/08/04 10:59:45 gray Exp $
+   $Id: info-utils.c,v 1.9 2007/12/03 01:38:42 karl Exp $
 
    Copyright (C) 1993, 1998, 2003, 2004, 2007 Free Software Foundation, Inc.
 
@@ -249,7 +249,7 @@
   tmp_search.end = binding->end;
   tmp_search.flags = S_FoldCase | S_SkipDest;
 
-  searching_for_menu_items = (strcasecmp (label, INFO_MENU_ENTRY_LABEL) == 0);
+  searching_for_menu_items = (mbscasecmp (label, INFO_MENU_ENTRY_LABEL) == 0);
 
   while ((position = search_forward (label, &tmp_search)) != -1)
     {
Index: info/info.c
===================================================================
RCS file: /sources/texinfo/texinfo/info/info.c,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -r1.22 -r1.23
--- info/info.c 16 Nov 2007 23:44:41 -0000      1.22
+++ info/info.c 3 Dec 2007 01:49:07 -0000       1.23
@@ -1,5 +1,5 @@
 /* info.c -- Display nodes of Info files in multiple windows.
-   $Id: info.c,v 1.22 2007/11/16 23:44:41 karl Exp $
+   $Id: info.c,v 1.23 2007/12/03 01:49:07 karl Exp $
 
    Copyright (C) 1993, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
    2004, 2005, 2007 Free Software Foundation, Inc.
@@ -153,19 +153,6 @@
 #ifdef HAVE_SETLOCALE
   /* Set locale via LC_ALL.  */
   setlocale (LC_ALL, "");
-
-  /* But don't use translated messages in the case when
-     string width and length can differ */
-  if (MB_CUR_MAX > 1)
-    {
-      setenv("LANGUAGE", "C", 1);
-      setenv("LANG", "C", 1);
-#ifdef LC_MESSAGES
-      setlocale (LC_MESSAGES, "C");
-#endif
-      setenv("LC_CTYPE", "C", 1);
-      setenv("LC_ALL", "C", 1);
-    }
 #endif /* HAVE_SETLOCALE */
 
 #ifdef ENABLE_NLS
Index: info/infodoc.c
===================================================================
RCS file: /sources/texinfo/texinfo/info/infodoc.c,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -r1.15 -r1.16
--- info/infodoc.c      23 Nov 2007 22:16:21 -0000      1.15
+++ info/infodoc.c      3 Dec 2007 01:38:42 -0000       1.16
@@ -1,5 +1,5 @@
 /* infodoc.c -- functions which build documentation nodes.
-   $Id: infodoc.c,v 1.15 2007/11/23 22:16:21 karl Exp $
+   $Id: infodoc.c,v 1.16 2007/12/03 01:38:42 karl Exp $
 
    Copyright (C) 1993, 1997, 1998, 1999, 2001, 2002, 2003, 2004, 2006, 2007
    Free Software Foundation, Inc.
@@ -517,7 +517,7 @@
     for (win = windows; win; win = win->next)
       {
         if (win->node && win->node->filename &&
-            (strcasecmp
+            (mbscasecmp
              (filename_non_directory (win->node->filename), "info") == 0) &&
             ((strcmp (win->node->nodename, "Help") == 0) ||
              (strcmp (win->node->nodename, "Help-Small-Screen") == 0)))
Index: info/man.c
===================================================================
RCS file: /sources/texinfo/texinfo/info/man.c,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- info/man.c  1 Sep 2007 00:05:24 -0000       1.10
+++ info/man.c  3 Dec 2007 01:38:42 -0000       1.11
@@ -1,5 +1,5 @@
 /*  man.c: How to read and format man files.
-    $Id: man.c,v 1.10 2007/09/01 00:05:24 karl Exp $
+    $Id: man.c,v 1.11 2007/12/03 01:38:42 karl Exp $
 
    Copyright (C) 1995, 1997, 1998, 1999, 2000, 2002, 2003, 2004, 2005, 2007
    Free Software Foundation, Inc.
@@ -454,7 +454,7 @@
 
       for (i = 0; (tag = file_buffer->tags[i]); i++)
         {
-          if (strcasecmp (pagename, tag->nodename) == 0)
+          if (mbscasecmp (pagename, tag->nodename) == 0)
             break;
         }
     }
Index: info/nodemenu.c
===================================================================
RCS file: /sources/texinfo/texinfo/info/nodemenu.c,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- info/nodemenu.c     1 Jul 2007 21:20:30 -0000       1.8
+++ info/nodemenu.c     3 Dec 2007 01:38:42 -0000       1.9
@@ -1,5 +1,5 @@
 /* nodemenu.c -- produce a menu of all visited nodes.
-   $Id: nodemenu.c,v 1.8 2007/07/01 21:20:30 karl Exp $
+   $Id: nodemenu.c,v 1.9 2007/12/03 01:38:42 karl Exp $
 
    Copyright (C) 1993, 1997, 1998, 2002, 2003, 2004, 2007
    Free Software Foundation, Inc.
@@ -115,7 +115,7 @@
   char **e1 = (char **) entry1;
   char **e2 = (char **) entry2;
 
-  return (strcasecmp (*e1, *e2));
+  return (mbscasecmp (*e1, *e2));
 }
 
 /* The name of the nodemenu node. */
Index: info/nodes.c
===================================================================
RCS file: /sources/texinfo/texinfo/info/nodes.c,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- info/nodes.c        1 Jul 2007 21:20:30 -0000       1.9
+++ info/nodes.c        3 Dec 2007 01:38:43 -0000       1.10
@@ -1,5 +1,5 @@
 /* nodes.c -- how to get an Info file and node.
-   $Id: nodes.c,v 1.9 2007/07/01 21:20:30 karl Exp $
+   $Id: nodes.c,v 1.10 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 1993, 1998, 1999, 2000, 2002, 2003, 2004, 2006, 2007
    Free Software Foundation, Inc.
@@ -118,8 +118,8 @@
   /* If the node not found was "Top", try again with different case,
      unless this was a man page.  */
   if (!node
-      && strcasecmp (filename, MANPAGE_FILE_BUFFER_NAME) != 0
-      && (nodename == NULL || strcasecmp (nodename, "Top") == 0))
+      && mbscasecmp (filename, MANPAGE_FILE_BUFFER_NAME) != 0
+      && (nodename == NULL || mbscasecmp (nodename, "Top") == 0))
     {
       node = info_get_node_of_file_buffer ("Top", file_buffer);
       if (!node)
@@ -294,7 +294,7 @@
 #if defined (HANDLE_MAN_PAGES)
   /* If the name of the file that we want is our special file buffer for
      Unix manual pages, then create the file buffer, and return it now. */
-  if (strcasecmp (filename, MANPAGE_FILE_BUFFER_NAME) == 0)
+  if (mbscasecmp (filename, MANPAGE_FILE_BUFFER_NAME) == 0)
     file_buffer = create_manpage_file_buffer ();
   else
 #endif /* HANDLE_MAN_PAGES */
@@ -331,7 +331,7 @@
      doesn't exist, then try again with the last part of the filename
      appearing in lowercase. */
   /* This is probably not needed at all on those systems which define
-     FILENAME_CMP to be strcasecmp.  But let's do it anyway, lest some
+     FILENAME_CMP to be mbscasecmp.  But let's do it anyway, lest some
      network redirector supports case sensitivity.  */
   if (retcode < 0)
     {
Index: makeinfo/footnote.c
===================================================================
RCS file: /sources/texinfo/texinfo/makeinfo/footnote.c,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -r1.11 -r1.12
--- makeinfo/footnote.c 1 Jul 2007 21:20:32 -0000       1.11
+++ makeinfo/footnote.c 3 Dec 2007 01:38:43 -0000       1.12
@@ -1,5 +1,5 @@
 /* footnote.c -- footnotes for Texinfo.
-   $Id: footnote.c,v 1.11 2007/07/01 21:20:32 karl Exp $
+   $Id: footnote.c,v 1.12 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 1998, 1999, 2002, 2007 Free Software Foundation, Inc.
 
@@ -59,9 +59,9 @@
 int
 set_footnote_style (char *string)
 {
-  if (strcasecmp (string, "separate") == 0)
+  if (mbscasecmp (string, "separate") == 0)
     footnote_style = separate_node;
-  else if (strcasecmp (string, "end") == 0)
+  else if (mbscasecmp (string, "end") == 0)
     footnote_style = end_node;
   else
     return -1;
Index: makeinfo/html.c
===================================================================
RCS file: /sources/texinfo/texinfo/makeinfo/html.c,v
retrieving revision 1.40
retrieving revision 1.41
diff -u -r1.40 -r1.41
--- makeinfo/html.c     15 Sep 2007 23:48:45 -0000      1.40
+++ makeinfo/html.c     3 Dec 2007 01:38:43 -0000       1.41
@@ -1,5 +1,5 @@
 /* html.c -- html-related utilities.
-   $Id: html.c,v 1.40 2007/09/15 23:48:45 karl Exp $
+   $Id: html.c,v 1.41 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
    Free Software Foundation, Inc.
@@ -659,10 +659,10 @@
      exact node on its file.  This is so several nodes could share the
      same file, in case of file-name clashes, but also for more
      accurate browser positioning.  */
-  if (strcasecmp (nodename, "(dir)") == 0)
+  if (mbscasecmp (nodename, "(dir)") == 0)
     /* Strip the parens, but keep the original letter-case.  */
     add_word_args ("%.3s", nodename + 1);
-  else if (strcasecmp (nodename, "top") == 0)
+  else if (mbscasecmp (nodename, "top") == 0)
     add_word ("Top");
   else
     add_escaped_anchor_name (nodename, href < 0);
@@ -727,7 +727,7 @@
   char *filename;
   char dirname[PATH_MAX];
 
-  if (strcasecmp (nodename, "Top") == 0)
+  if (mbscasecmp (nodename, "Top") == 0)
     {
       /* We want to convert references to the Top node into
         "index.html#Top".  */
@@ -736,7 +736,7 @@
       else
        filename = xstrdup ("Top");
     }
-  else if (strcasecmp (nodename, "(dir)") == 0)
+  else if (mbscasecmp (nodename, "(dir)") == 0)
     /* We want to convert references to the (dir) node into
        "../index.html".  */
     filename = xstrdup ("../index.html");
Index: makeinfo/index.c
===================================================================
RCS file: /sources/texinfo/texinfo/makeinfo/index.c,v
retrieving revision 1.25
retrieving revision 1.26
diff -u -r1.25 -r1.26
--- makeinfo/index.c    26 Sep 2007 20:53:40 -0000      1.25
+++ makeinfo/index.c    3 Dec 2007 01:38:43 -0000       1.26
@@ -1,5 +1,5 @@
 /* index.c -- indexing for Texinfo.
-   $Id: index.c,v 1.25 2007/09/26 20:53:40 karl Exp $
+   $Id: index.c,v 1.26 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 1998, 1999, 2002, 2003, 2004, 2007
    Free Software Foundation, Inc.
@@ -49,7 +49,7 @@
 static INDEX_ELT **the_indices = NULL;
 
 /* How to compare index entries for sorting.  May be set to strcoll.  */
-static int (*index_compare_fn) (const char *a, const char *b) = strcasecmp;
+static int (*index_compare_fn) (const char *a, const char *b) = mbscasecmp;
 
 /* Find which element in the known list of indices has this name.
    Returns -1 if NAME isn't found. */
Index: makeinfo/lang.c
===================================================================
RCS file: /sources/texinfo/texinfo/makeinfo/lang.c,v
retrieving revision 1.33
retrieving revision 1.34
diff -u -r1.33 -r1.34
--- makeinfo/lang.c     8 Oct 2007 18:22:27 -0000       1.33
+++ makeinfo/lang.c     3 Dec 2007 01:38:43 -0000       1.34
@@ -1,5 +1,5 @@
 /* lang.c -- language-dependent support.
-   $Id: lang.c,v 1.33 2007/10/08 18:22:27 karl Exp $
+   $Id: lang.c,v 1.34 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
    Free Software Foundation, Inc.
@@ -1211,7 +1211,7 @@
   /* If we didn't find one to copy, warn and duplicate.  */
   if (c == principal_len)
     {
-      if (strcasecmp (ll_code, "en") == 0)
+      if (mbscasecmp (ll_code, "en") == 0)
         cc_code = xstrdup ("en_US");
       else
         {
@@ -1386,7 +1386,7 @@
       /* See if we have this encoding.  */
       for (enc = no_encoding+1; enc != last_encoding_code; enc++)
         {
-          if (strcasecmp (enc_arg, encoding_table[enc].encname) == 0)
+          if (mbscasecmp (enc_arg, encoding_table[enc].encname) == 0)
             {
               document_encoding_code = enc;
               break;
Index: makeinfo/makeinfo.c
===================================================================
RCS file: /sources/texinfo/texinfo/makeinfo/makeinfo.c,v
retrieving revision 1.112
retrieving revision 1.113
diff -u -r1.112 -r1.113
--- makeinfo/makeinfo.c 24 Oct 2007 20:03:35 -0000      1.112
+++ makeinfo/makeinfo.c 3 Dec 2007 01:38:43 -0000       1.113
@@ -1,5 +1,5 @@
 /* makeinfo -- convert Texinfo source into other formats.
-   $Id: makeinfo.c,v 1.112 2007/10/24 20:03:35 karl Exp $
+   $Id: makeinfo.c,v 1.113 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 1987, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999,
    2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
@@ -3726,7 +3726,7 @@
     {
       if (array_len (arglist) > 1)
         {
-          if ((strcasecmp (arglist[0], arglist[1]) == 0) &&
+          if ((mbscasecmp (arglist[0], arglist[1]) == 0) &&
               (arglist[2]))
             execute_string ("%s\n", arglist[2]);
         }
Index: makeinfo/node.c
===================================================================
RCS file: /sources/texinfo/texinfo/makeinfo/node.c,v
retrieving revision 1.39
retrieving revision 1.40
diff -u -r1.39 -r1.40
--- makeinfo/node.c     24 Oct 2007 20:03:35 -0000      1.39
+++ makeinfo/node.c     3 Dec 2007 01:38:43 -0000       1.40
@@ -1,5 +1,5 @@
 /* node.c -- nodes for Texinfo.
-   $Id: node.c,v 1.39 2007/10/24 20:03:35 karl Exp $
+   $Id: node.c,v 1.40 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2007
    Free Software Foundation, Inc.
@@ -136,7 +136,7 @@
 static void
 normalize_node_name (char *string)
 {
-  if (strcasecmp (string, "Top") == 0)
+  if (mbscasecmp (string, "Top") == 0)
     strcpy (string, "Top");
 }
 
@@ -581,7 +581,7 @@
   if (html && splitting
       /* If there is a Top node, it always goes into index.html.  So
         don't start a new HTML file for Top.  */
-      && (top_node_seen || strcasecmp (node, "Top") != 0))
+      && (top_node_seen || mbscasecmp (node, "Top") != 0))
     {
       /* We test *node here so that @node without a valid name won't
         start a new file name with a bogus name such as ".html".
@@ -843,7 +843,7 @@
                   prev = xstrdup (ref->next->node);
                 }
               else if (!ref->next
-                       && strcasecmp (ref->containing_node, "Top") == 0)
+                       && mbscasecmp (ref->containing_node, "Top") == 0)
                 {
                   free (prev);
                   prev = xstrdup (ref->containing_node);
@@ -949,7 +949,7 @@
                                output_stream) == NULL
                      /* Paranoia: did someone change the way HTML
                         files are finished up?  */
-                     || strcasecmp (end_line, html_end) != 0)
+                     || mbscasecmp (end_line, html_end) != 0)
                    {
                      line_error (_("Unexpected string at end of split-HTML 
file `%s'"),
                                  fname_for_this_node);
@@ -1529,7 +1529,7 @@
 
       if (!tags->up
           && !(tags->flags & TAG_FLAG_ANCHOR)
-          && strcasecmp (tags->node, "Top") != 0)
+          && mbscasecmp (tags->node, "Top") != 0)
         line_error (_("`%s' has no Up field (perhaps incorrect sectioning?)"), 
tags->node);
       else if (tags->up)
         {
@@ -1629,7 +1629,7 @@
           /* Notice that the node "Top" is special, and doesn't have to
              be referenced.   Anchors don't have to be referenced
              either, you might define them for another document.  */
-          if (strcasecmp (tags->node, "Top") != 0
+          if (mbscasecmp (tags->node, "Top") != 0
               && !(tags->flags & TAG_FLAG_ANCHOR))
             warning (_("unreferenced node `%s'"), tags->node);
         }
Index: makeinfo/xml.c
===================================================================
RCS file: /sources/texinfo/texinfo/makeinfo/xml.c,v
retrieving revision 1.73
retrieving revision 1.74
diff -u -r1.73 -r1.74
--- makeinfo/xml.c      24 Oct 2007 20:03:36 -0000      1.73
+++ makeinfo/xml.c      3 Dec 2007 01:38:43 -0000       1.74
@@ -1,5 +1,5 @@
 /* xml.c -- xml output, both TexinfoML and Docbook.
-   $Id: xml.c,v 1.73 2007/10/24 20:03:36 karl Exp $
+   $Id: xml.c,v 1.74 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
    Free Software Foundation, Inc.
@@ -605,7 +605,7 @@
   int i;
   for (i = 0; i<=PARA; i++)
     {
-      if (strcasecmp (name, texinfoml_element_list[i].name) == 0)
+      if (mbscasecmp (name, texinfoml_element_list[i].name) == 0)
         return i;
     }
   printf ("Error xml_element\n");
@@ -1367,15 +1367,15 @@
       /* Let's assume it started.  */
       quotation_started = 1;
 
-      if (strcasecmp (type, "tip") == 0)
+      if (mbscasecmp (type, "tip") == 0)
         xml_insert_element (TIP, arg);
-      else if (strcasecmp (type, "note") == 0)
+      else if (mbscasecmp (type, "note") == 0)
         xml_insert_element (NOTE, arg);
-      else if (strcasecmp (type, "important") == 0)
+      else if (mbscasecmp (type, "important") == 0)
         xml_insert_element (IMPORTANT, arg);
-      else if (strcasecmp (type, "warning") == 0)
+      else if (mbscasecmp (type, "warning") == 0)
         xml_insert_element (WARNING, arg);
-      else if (strcasecmp (type, "caution") == 0)
+      else if (mbscasecmp (type, "caution") == 0)
         xml_insert_element (CAUTION, arg);
       else
         /* Didn't find a known quotation type :\ */
Index: util/install-info.c
===================================================================
RCS file: /sources/texinfo/texinfo/util/install-info.c,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -r1.19 -r1.20
--- util/install-info.c 21 Sep 2007 22:49:26 -0000      1.19
+++ util/install-info.c 3 Dec 2007 01:38:43 -0000       1.20
@@ -1,5 +1,5 @@
 /* install-info -- create Info directory entry(ies) for an Info file.
-   $Id: install-info.c,v 1.19 2007/09/21 22:49:26 karl Exp $
+   $Id: install-info.c,v 1.20 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
    2005, 2007 Free Software Foundation, Inc.
@@ -410,7 +410,7 @@
   }
     
   /* First, ITEM must actually match NAME (usually it won't).  */
-  ret = strncasecmp (item_basename, name, name_len) == 0;
+  ret = mbsncasecmp (item_basename, name, name_len) == 0;
   if (ret)
     {
       /* Then, `foobar' doesn't match `foo', so be sure we've got all of
@@ -428,7 +428,7 @@
         {
           char *suffix = suffixes[i];
           unsigned suffix_len = strlen (suffix);
-          ret = strncasecmp (item_basename + name_len, suffix, suffix_len) == 0
+          ret = mbsncasecmp (item_basename + name_len, suffix, suffix_len) == 0
                 && item_basename[name_len + suffix_len] == term_char;
         }
     }
P ChangeLog
P system.h
P gnulib/lib/.cvsignore
P gnulib/lib/Makefile.am
P gnulib/lib/mbchar.c
P gnulib/lib/mbchar.h
P gnulib/lib/mbuiter.h
P gnulib/lib/memchr.c
cvs update: `gnulib/lib/strcasecmp.c' is no longer in the repository
cvs update: `gnulib/lib/strncasecmp.c' is no longer in the repository
P gnulib/lib/strnlen1.c
P gnulib/lib/strnlen1.h
P gnulib/m4/.cvsignore
P gnulib/m4/gnulib-cache.m4
P gnulib/m4/gnulib-comp.m4
P gnulib/m4/mbchar.m4
cvs update: `gnulib/m4/strcase.m4' is no longer in the repository
P info/echo-area.c
P info/filesys.c
P info/info-utils.c
P info/info.c
P info/infodoc.c
P info/man.c
P info/nodemenu.c
P info/nodes.c
P info/session.c
P makeinfo/footnote.c
P makeinfo/html.c
P makeinfo/index.c
P makeinfo/lang.c
P makeinfo/makeinfo.c
P makeinfo/node.c
P makeinfo/xml.c
P util/install-info.c




reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: info/session.c
===================================================================
RCS file: /sources/texinfo/texinfo/info/session.c,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -r1.20 -r1.21
--- info/session.c      4 Aug 2007 11:00:43 -0000       1.20
+++ info/session.c      3 Dec 2007 01:38:43 -0000       1.21
@@ -1,5 +1,5 @@
 /* session.c -- user windowing interface to Info.
-   $Id: session.c,v 1.20 2007/08/04 11:00:43 gray Exp $
+   $Id: session.c,v 1.21 2007/12/03 01:38:43 karl Exp $
 
    Copyright (C) 1993, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
    2004, 2007 Free Software Foundation, Inc.
@@ -2373,9 +2373,9 @@
 
           for (i = 0; menu && (ref = menu[i]); i++)
             {
               /* Need to use strcasecmp because LINE is downcased
                  inside info_read_completing_in_echo_area.  */
-              if (strcasecmp (line, ref->label) == 0)
+              if (mbscasecmp (line, ref->label) == 0)
                 {
                   /* ref->end is more accurate estimate of position
                      for menus than ref->start.  Go figure.  */
@@ -2653,11 +2653,11 @@
 
           for (i = 0; (entry = menu[i]); i++)
             {
-              if (strcasecmp (entry->label, arg) == 0)
+              if (mbscasecmp (entry->label, arg) == 0)
                 break;
               else
                 if ((best_guess == -1)
-                    && (strncasecmp (entry->label, arg, strlen (arg)) == 0))
+                    && (mbsncasecmp (entry->label, arg, strlen (arg)) == 0))
                   best_guess = i;
             }
 
@@ -2834,10 +2834,10 @@
 
       for (i = 0; (entry = menu[i]); i++)
        {
-         if (strcasecmp (entry->label, arg) == 0)
+         if (mbscasecmp (entry->label, arg) == 0)
            break;
          else
-           if (strncasecmp (entry->label, arg, strlen (arg)) == 0)
+           if (mbsncasecmp (entry->label, arg, strlen (arg)) == 0)
              best_guess = i;
        }
 
@@ -4245,12 +4245,12 @@
              we are looking at it, then don't bother calling the search
              function. */
           if (((dir < 0) &&
-              ((case_sensitive ? strncmp : strncasecmp)
+              ((case_sensitive ? strncmp : mbsncasecmp)
                             (window->node->contents + window->point,
                              isearch_string, isearch_string_index) == 0)) ||
               ((dir > 0) &&
                ((window->point - isearch_string_index) >= 0) &&
-              ((case_sensitive ? strncmp : strncasecmp)
+              ((case_sensitive ? strncmp : mbsncasecmp)
                             (window->node->contents +
                              (window->point - (isearch_string_index - 1)),
                              isearch_string, isearch_string_index) == 0)))
@@ -2373,9 +2373,9 @@
           for (i = 0; menu && (ref = menu[i]); i++)
             {
-              /* Need to use strcasecmp because LINE is downcased
+              /* Need to use mbscasecmp because LINE is downcased
                  inside info_read_completing_in_echo_area.  */